@@ -68,6 +68,7 @@ def get_entity_list_from_remote(
     keyword_search: Text = "",
     page_size: int = 1,
     page_number: int = 10,
+    authtoken: Text = None,
 ) -> Tuple[List[Dict[Text, Any]], int]:
     payload = {
         FILTER: {ENTITY_TYPE: entity_type, LANGUAGE: language},
@@ -76,7 +77,7 @@ def get_entity_list_from_remote(
         PAGE_SIZE: page_size,
     }
     HEADERS = copy(COMMON_HEADERS)
-    HEADERS[AUTHORIZATION] = get_auth_token()
+    HEADERS[AUTHORIZATION] = authtoken if authtoken is not None else get_auth_token()
 
     response = requests.request(
         "POST",
@@ -94,7 +95,9 @@ def get_entity_list_from_remote(
     return json_response[DATA][ENTITIES], json_response[DATA][COUNT]
 
 
-def auto_tag_pretrained_entities(data: List[Dict[Text, Any]], language: Text):
+def auto_tag_pretrained_entities(
+    data: List[Dict[Text, Any]], language: Text, authtoken: Text = None
+):
     sample_pretrained_entities, count = get_entity_list_from_remote(
         entity_type=PRE_TRAINED, language=language
     )
@@ -103,6 +106,7 @@ def auto_tag_pretrained_entities(data: List[Dict[Text, Any]], language: Text):
         language=language,
         page_number=1,
         page_size=count,
+        authtoken=authtoken,
     )
     all_pretrained_entity_names = {
         entity[ENTITY]: entity[ENTITY] for entity in all_pretrained_entities
